@@ -8,15 +8,21 @@ class Client(object):
     def __init__(self, api_credentials):
         self.api_credentials = api_credentials
 
-    def _get_response(self, http_method, endpoint, data=None, **request_kwargs):
+    def get_factory(self, files):
+        if files:
+            return factory.MultipartSignedRequestFactory
+        return factory.SignedRequestFactory
+
+    def _get_response(self, http_method, endpoint, data=None, files=None, **request_kwargs):
         try:
-            http_response = urllib2.urlopen(self._get_request(http_method, endpoint, data, **request_kwargs))
+            http_response = urllib2.urlopen(self._get_request(http_method, endpoint, data, files, **request_kwargs))
         except urllib2.HTTPError as e:
             http_response = e
         return response.Response(http_response)
 
-    def _get_request(self, http_method, endpoint, data=None, **request_kwargs):
-        request_factory = factory.SignedRequestFactory(http_method, self._client_id, self._private_key, data)
+    def _get_request(self, http_method, endpoint, data=None, files=None, **request_kwargs):
+        factory_class = self.get_factory(files)
+        request_factory = factory_class(http_method, self._client_id, self._private_key, data, files)
         service_url = self._get_service_url(endpoint)
         return request_factory.create_request(service_url, **request_kwargs)
 
